################################################################################
#
# Point process modeling via process convolutions
# Copyright (C) 2011, University of California
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Questions? Contact Waley W. Liang (wliang@ams.ucsc.edu)
#
################################################################################

source("ppm.main.R")
source("ppm.plots.R")

makeplots <- FALSE
print <- FALSE
poster <- FALSE
output.file <- "ppm.static.JanToDec.RData"

## Run static model
set.seed(10)
runtime <-
  system.time(mcmc <-
              main(domain = cbind(c(-84.65, -84.37), c(39.09, 39.23)),
                   grid.data.file = "polycentresData.csv",
                   crime.data.file = "crimeclass1points.csv",
                   burnin = 1000, iter = 2000, proposal = 2,
                   kernel.fun = "bezier", kernel.w = 3, kernel.l = 3,
                   num.kern.lon = 40, num.kern.lat = 20,
                   pro.zu.a = 15, pro.zu.del = 0.5,
                   pri.zu.shape = 1, pri.zu.rate = 1,
                   pri.beta.mean = c(0, 0), pri.beta.sd = c(1, 1),
                   pri.phi.sd = c(1, 1), pro.beta.sd = c(0.15, 0.25),
                   pro.phi.sd = c(0.1, 0.1), zu.init = 0.001,
                   tau = (3857 / (12 * 138)), beta.init = c(0, 0),
                   phi.init = c(0, 0, 0, 0), output.file = output.file))

if (makeplots) {
  load(output.file)
  
  plot.obsv.window(mcmc, plot.obsv = TRUE, plot.grid = FALSE, regular = FALSE,
                   file = (if (print) "obsv_window" else ""),
                   main = "Cincinnati crime data in 2006", width = 6.5, height = 5)
  

  plot.obsv.window(mcmc, plot.obsv = FALSE, plot.grid = TRUE, regular = FALSE,
                   file = (if (print) "obsv_window_grid" else ""),
                   main = "Map of Cincinnati", width = 6.5, height = 5)

  
  plot.obsv.window(mcmc, plot.obsv = TRUE, plot.kern = TRUE,
                   file = (if (print) "obsv_window_kern" else ""),
                   main = "Cincinnati crime data in 2006", width = 6.5, height = 5)
  
  ## Plot spatial effects of population density and vacancy rates  
  plot.spatial.effect(mcmc, file = (if (print) "spatial_effect_nd" else ""), breaks = 10)
  
  ## Plot monthly effect
  plot.time.effect(mcmc, file = (if (print) "time_effect_nd" else ""))
  
  ## Plot baseline intensity
  plot.intensity(mcmc, theta = 30, nlevels = 20, spatial = F, time = F, t = 6,
                 file = (if (print) "baseline_nd" else ""), zlim = c(0, 100),
                 landscape = (if (poster) FALSE else TRUE),
                 width = 6.5, height = 5, main = "Fitted baseline")
  
  ## Plot baseline intensity * spatial effect
  plot.intensity(mcmc, theta = 30, nlevels = 20, spatial = T, time = F, t = 6,
                 file = (if (print) "baseline_spatial_nd" else ""), zlim = c(0, 100),
                 landscape = (if (poster) FALSE else TRUE),
                 width = 6.5, height = 5, main = "Fitted baseline * spatial effect")
  
  ## Plot baseline intensity * spatial effect * month effect (June)
  plot.intensity(mcmc, theta = 30, nlevels = 20, spatial = T, time = T, t = 6,
                 file = (if (print) "baseline_spatial_time_june_nd" else ""),
                 zlim = c(0, 100), landscape = (if (poster) FALSE else TRUE),
                 width = 6.5, height = 5,
                 main = "Fitted baseline * spatial effect * time effect for June")
}


